==> dal_docx_creator-0.0.1.tar.gz: dal_docx_creator-0.0.1/dal_docx_creator/example/__init__.py <==
"""
Module to hold some inspirational examples.

Tutorial here:
- https://python-docx.readthedocs.io/en/latest/
"""
from docx import Document


__all__ = [
    'DocxExample'
]

class DocxExample:
    """
    Class to wrap some example of PFDs.
    """

    @staticmethod
    def test_one():
        document = Document()

        document.add_heading('Document Title', 0)

        p = document.add_paragraph('A plain paragraph having some ')
        p.add_run('bold').bold = True
        p.add_run(' and some ')
        p.add_run('italic.').italic = True

        document.add_heading('Heading, level 1', level=1)
        document.add_paragraph('Intense quote', style='Intense Quote')

        document.add_paragraph(
            'first item in unordered list', style='List Bullet'
        )
        document.add_paragraph(
            'first item in ordered list', style='List Number'
        )

        #document.add_picture('monty-truth.png', width=Inches(1.25))

        records = (
            (3, '101', 'Spam'),
            (7, '422', 'Eggs'),
            (4, '631', 'Spam, spam, eggs, and spam')
        )

        table = document.add_table(rows=1, cols=3)
        hdr_cells = table.rows[0].cells
        hdr_cells[0].text = 'Qty'
        hdr_cells[1].text = 'Id'
        hdr_cells[2].text = 'Desc'
        for qty, id, desc in records:
            row_cells = table.add_row().cells
            row_cells[0].text = str(qty)
            row_cells[1].text = id
            row_cells[2].text = desc

        document.add_page_break()

==> dal_docx_creator-0.0.2.tar.gz: dal_docx_creator-0.0.2/dal_docx_creator/example/__init__.py <==
"""
Module to hold some inspirational examples.

Tutorial here:
- https://python-docx.readthedocs.io/en/latest/
"""
from dal_docx_creator.creator import DocxCreator
from docx import Document


__all__ = [
    'DocxExample'
]

class DocxExample:
    """
    Class to wrap some example of DOCXs.
    """

    @staticmethod
    def test_one():
        print('here in test')
        document = Document()

        document.add_heading('Document Title', 0)

        p = document.add_paragraph('A plain paragraph having some ')
        p.add_run('bold').bold = True
        p.add_run(' and some ')
        p.add_run('italic.').italic = True

        document.add_heading('Heading, level 1', level=1)
        document.add_paragraph('Intense quote', style='Intense Quote')

        document.add_paragraph(
            'first item in unordered list', style='List Bullet'
        )
        document.add_paragraph(
            'first item in ordered list', style='List Number'
        )

        #document.add_picture('monty-truth.png', width=Inches(1.25))

        records = (
            (3, '101', 'Spam'),
            (7, '422', 'Eggs'),
            (4, '631', 'Spam, spam, eggs, and spam')
        )

        table = document.add_table(rows=1, cols=3)
        hdr_cells = table.rows[0].cells
        hdr_cells[0].text = 'Qty'
        hdr_cells[1].text = 'Id'
        hdr_cells[2].text = 'Desc'
        for qty, id, desc in records:
            row_cells = table.add_row().cells
            row_cells[0].text = str(qty)
            row_cells[1].text = id
            row_cells[2].text = desc

        document.add_page_break()

        print('storing')
        DocxCreator.create(document, 'test_simple.docx')
